


function [header B1 B0 mask SODA]=read_fld_file(filepath)
% function [header B1 B0 mask SODA]=read_fld_file(filepath)

file=fopen(filepath,'rb');

% header
header.magic=fread(file,1,'int32');
if header.magic ~= hex2dec('70747866')
    error('Incorrect magic number (1).');
end
header.gamma=fread(file,1,'float32');
header.nvoxels=fread(file,1,'int32');
header.ncoils=fread(file,1,'int32');

% B1+
B1=read_matrix(file);
B1.data=B1.data(1:2:end,:) + 1j*B1.data(2:2:end,:);

% B0
B0=read_matrix(file);

% mask
mask=read_matrix(file);

header.nslices=fread(file,1,'int32');

% slice information
SODA=read_SODA(file);

fclose(file);



function mat=read_matrix(file)

mat.magic=fread(file,1,'int32');
if mat.magic ~= hex2dec('6D617472')
    error('Incorrect magic number (1).');
end
mat.nrows=fread(file,1,'int32');
mat.ncols=fread(file,1,'int32');
mat.typeSize=fread(file,1,'int32');

mat.reserved=fread(file,1,'int32');

b0flag=0;
fac=1;
if mat.typeSize==1
    str='int8';
elseif mat.typeSize==2
    str='int16';
elseif mat.typeSize==4
    str='float';
elseif mat.typeSize==8
    str='float';
    fac=2;
elseif mat.typeSize==16
    str='float';
    b0flag=1;
else
    error('Unrecognize data type.');
end
            
if b0flag==0
    mat.data=reshape( fread(file,fac*mat.nrows*mat.ncols,str),fac*mat.nrows,mat.ncols );
else
    temp=fread(file,4*mat.nrows*mat.ncols,str);
    mat.data=temp(1:4:end);
    % mat.data=temp(1:128^2);
    mat.xs=temp(2:4:end);
    mat.ys=temp(3:4:end);
    mat.zs=temp(4:4:end);
end
    




function xB0DataType=read_xB0DataType(file)

xB0DataType.B0=fread(file,1,'float');

xB0DataType.x=fread(file,1,'float');
xB0DataType.y=fread(file,1,'float');
xB0DataType.z=fread(file,1,'float');




function SODA=read_SODA(file)

SODA.UpperLeftCornerImage=fread(file,3,'float');
SODA.Left2RightDirection=fread(file,3,'float');
SODA.Up2DownDirection=fread(file,3,'float');

SODA.VoxelWidth=fread(file,1,'float');
SODA.VoxelHeight=fread(file,1,'float');

SODA.ncols=fread(file,1,'int32');
SODA.nrows=fread(file,1,'int32');

SODA.ImageOrientation=fread(file,1,'int8');  % 0: TRA, 1: SAG, 2: COR
SODA.PhaseEncodingDirection=fread(file,1,'int8');  % 0: std, 1: swapped






























